@@ -489,8 +489,10 @@ class BaseExperiment:
         self.logger = pl_loggers.TensorBoardLogger(save_dir=self.log_path+"/tensorboardlogs/" + self.model.__class__.__name__, name=self.model_metadata)
 
         if torch.cuda.is_available():
-            trainer_setting.update({'gpus' : -1})
-            trainer_setting.update({'accelerator' : 'gpu'})
+            if 'accelerator' in trainer_setting.keys():
+                if trainer_setting['accelerator']=='gpu':
+                    trainer_setting.update({'gpus' : -1})
+                    trainer_setting.update({'accelerator' : 'gpu'})
         if 'min_epochs' not in trainer_config.keys():
             trainer_setting.update({'min_epochs' : 10})
         if 'max_epochs' not in trainer_config.keys():
