@@ -1,7 +1,7 @@
 from astrape.models.models_lightning import MLP, ContractingMLP, CustomMLP, VGG, UNet
 from astrape.models.model_buildingblocks import DoubleConv, Down, Up
 from astrape.utilities.utils_lightning import set_default_parameters
-from astrape.utilities.utils import rearrange_dims
+
 #from astrape.constants import DEFAULT_BATCH_SIZE, DEFAULT_LR, DEFAULT_OPTIMIZER_TYPE
 __all__ = [
     'MLP', 
@@ -12,6 +12,5 @@ __all__ = [
     'DoubleConv', 
     'Down', 
     'Up', 
-    'set_default_parameters',
-    'rearrange_dims'
+    'set_default_parameters'
     ]
