@@ -302,3 +302,34 @@ def divide_set(X, y, column, value):
     y_set_2 = [element[1] for element in set_2]
 
     return X_set_1, y_set_1, X_set_2, y_set_2
+
+def rearrange_dims(dims, dataformats="NCHW"):
+    if isinstance(dims, int):
+            raise ValueError(f"Wrong dimension {dims} for an input.")
+    elif len(dims) == 2:
+        height = dims[0]
+        width = dims[1]
+        dims = (1, height, width)
+    elif len(dims) == 3:
+        if dataformats == "NCHW":
+            dims = dims
+        elif dataformats == "NHCW":
+            height, channels, width = dims
+            dims = (channels, height, width)
+        elif dataformats == "NHWC":
+            height, width, channels = dims
+            dims = (channels, height, width)
+        elif dataformats == "NCWH":
+            channels, width, height = dims
+            dims = (channels, height, width)
+        elif dataformats == "NWHC":
+            width, height, channels = dims
+            dims = (channels, height, width)
+        elif dataformats == "NWCH":
+            width, channels, height = dims
+            dims = (channels, height, width)
+        else:
+            raise ValueError(f"Invalid dataformats {dataformats}. It should start with 'N' followed by permutation of 'HWC'.")
+    else:
+        raise ValueError(f"Wrong dimension {dims} for an input.")
+    return dims
